@@ -1,7 +1,13 @@
 import { NativeAudio } from "@awesome-cordova-plugins/native-audio/ngx";
+// install native audio in peek-field-app
+//  reference: https://ionicframework.com/docs/native/native-audio
+// $ npm install cordova-plugin-nativeaudio
+// $ npm install @awesome-cordova-plugins/native-audio
+// $ npm install @awesome-cordova-plugins/core
+// $ npx cap sync
+import { PermissionType, Plugins } from "@capacitor/core";
 import { NotifierI } from "./notifier.interface";
-import { LocalNotifications } from "@capacitor/local-notifications";
-import { Dialog } from "@capacitor/dialog";
+const { LocalNotifications, Permissions, Modals } = Plugins;
 
 export class NativeNotifier implements NotifierI {
     private nativeAudio = new NativeAudio();
@@ -52,14 +58,16 @@ export class NativeNotifier implements NotifierI {
 
     async checkNotificationSettings(): Promise<void> {
         console.log("NATIVE NOTIFIER checking iOS permissions");
-        let permissionStatus = await LocalNotifications.checkPermissions();
+        const permission = await Permissions.query({
+            name: PermissionType.Notifications,
+        });
 
-        if (permissionStatus.display === "prompt") {
-            permissionStatus = await LocalNotifications.requestPermissions();
+        if (permission.state === "prompt") {
+            LocalNotifications.requestPermission();
+            return;
         }
-
-        if (permissionStatus.display === "denied") {
-            const confirmed = await Dialog.confirm({
+        if (permission.state === "denied") {
+            const confirmed = await Modals.confirm({
                 title: "Notifications Required",
                 message:
                     "Peek requires notifications to be enabled.\n" +
